# Copyright (C) 2008 Ansgar Wiechers <ansgar.wiechers@planetcobalt.net>
#
# This module is free software. You may use, redistribute and/or modify it
# under the terms of the GNU General Public License Version 2.0 as found at
# <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>.

package DB;

=head1 NAME

  FilterDB::DB -- Interface for database backends for the backscatter filter

=head1 SYNOPSIS

  package MyBackend;
  use FilterDB::DB;
  our @ISA = qw( DB );
  
  sub new {
    my ($class, %args) = @_;
    my $self = bless { %args }, $class;

    # further initialization here

    return $self;
  }

  sub check {
    # Check whether the hash of a given value is present in database backend.
    # Should return a boolean value.
  }
  
  sub cleanup {
    # Remove entries older than $max_age from database.
  }
  
  sub insert {
    # Insert hash of given value and current timestamp into database.
  }
  
  sub list {
    # List database contents.
    # Should return the entries in the database.
  }

  1;

=head1 DESCRIPTION

FilterDB::DB defines the interface every class encapsulating a database backend
must implement. Every derived class must implement the functions check(),
cleanup(), insert() and list() as layed out above.

=head1 AUTHOR

Ansgar Wiechers <ansgar.wiechers@planetcobalt.net>

=cut

use strict;
use warnings;

sub import {
	my $package = shift;
	return if $package eq __PACKAGE__;
	foreach my $method (qw( check cleanup insert list )) {
		$package->can($method)
			or die "Class $package does not define method $method().";
	}
	$package->SUPER::import(@_);
}

1;
